@@ -1,3 +1,3 @@
 """The Python package of the Oxynet project"""
 
-from .main import *
\ No newline at end of file
+from .utilities import *
\ No newline at end of file
